.. _publications:
.. index:: Publications

Publications
************

This page compiles publications that have utilized :program:`icet`.
If you want your own publication to show up in this list, please send
an email with the subject line "New publication: <paper title>" to
icet@materialsmodeling.org.

.. [XII]
   | E. Fransson, M. Gren, and G. Wahnström
   | *Complexions and grain growth retardation: First-principles modeling of phase boundaries in WC-Co cemented carbides at elevated temperatures*
   | Acta Materialia **216**, 117128 (2021)
   | `doi: 10.1016/j.actamat.2021.117128 <https://doi.org/10.1016/j.actamat.2021.117128>`_ 

.. [XI]
   | P. Ekborg-Tanner and P. Erhart
   | *Hydrogen-Driven Surface Segregation in Pd Alloys from Atomic-Scale Simulations*
   | Journal of Physical Chemstry C **125**, 17248 (2021)
   | `doi: 10.1021/acs.jpcc.1c00575 <https://doi.org/10.1021/acs.jpcc.1c00575>`_

.. [X]
   | J. Brorsson, Y. Zhang, A. E. C. Palmqvist, and P. Erhart
   | *Order–Disorder Transition in Inorganic Clathrates Controls Electrical Transport Properties*
   | Chemstry of Materials **33**, 4500 (2021)
   | `doi: 10.1021/acs.chemmater.1c00731 <https://doi.org/10.1021/acs.chemmater.1c00731>`_ 

.. [IX]
   | J. M. Rahm, J. Löfgren, E. Fransson, and P. Erhart
   | *A tale of two phase diagrams: Interplay of ordering and hydrogen uptake in Pd–Au–H*
   | Acta Materialia **211**, 116893 (2021)
   | `doi: 10.1016/j.actamat.2021.116893 <https://doi.org/10.1016/j.actamat.2021.116893>`_ 

.. [VIII]
   | M. Gren, E. Fransson, M. Ångqvist, P. Erhart, and Göran Wahnström
   | *Modeling of vibrational and configurational degrees of freedom in hexagonal and cubic tungsten carbide at high temperatures*
   | Physical Review Materials **5**, 033804 (2021)
   | `doi: 10.1103/PhysRevMaterials.5.033804 <https://doi.org/10.1103/PhysRevMaterials.5.033804>`_ 

.. [VII]
   | R. Ibragimova, P. Erhart, P. Rinke, and H.-P. Komsa
   | *Surface Functionalization of 2D MXenes: Trends in Distribution, Composition, and Electronic Properties*
   | The Journal of Physical Chemistry Letters **12**, 2377 (2021)
   | `doi: 10.1021/acs.jpclett.0c03710 <https://doi.org/10.1021/acs.jpclett.0c03710>`_ 

.. [VI]
   | M. Fant, M. Ångqvist, A. Hellman, P. Erhart
   | *To Every Rule There is an Exception: A Rational Extension of Loewenstein's Rule*
   | Angewandte Chemie **133**, 5192 (2021)
   | `doi: 10.1002/ange.202013256 <https://doi.org/10.1002/ange.202013256>`_ 

.. [V]
   | J. M. Rahm, C. Tiburski, T. P. Rossi, F. A. A. Nugroho, S. Nilsson, C. Langhammer, and P. Erhart
   | *A Library of Late Transition Metal Alloy Dielectric Functions for Nanophotonic Applications*
   | Advanced Functional Materials **30**, 2002122 (2020)
   | `doi: 10.1002/adfm.202002122 <https://doi.org/10.1002/adfm.202002122>`_ 

.. [IV]
   | M. Ångqvist, J. M. Rahm, L. Gharaee, and P. Erhart
   | *Structurally driven asymmetric miscibility in the phase diagram of W–Ti*
   | Physical Review Materials **3**, 30597 (2019)
   | `doi: 10.1103/PhysRevMaterials.3.073605 <https://doi.org/10.1103/PhysRevMaterials.3.073605>`_

.. [III]
   | M. Ångqvist, W. A. Muñoz, J. M. Rahm, E. Fransson, C. Durniak, P. Rozyczko, T. H. Rod, and P. Erhart
   | *ICET – A Python Library for Constructing and Sampling Alloy Cluster Expansions*
   | Advanced Theory and Simulations **2**, 1900015 (2019)
   | `doi: 10.1002/adts.201900015 <https://doi.org/10.1002/adts.201900015>`_

.. [II]
   | M. Ångqvist and P. Erhart
   | *Understanding chemical ordering in intermetallic clathrates from atomic scale simulations*
   | Chemistry of Materials **29**, 7554 (2017)
   | `doi: 10.1021/acs.chemmater.7b02686 <http://dx.doi.org/10.1021/acs.chemmater.7b02686>`_

.. [I]
   | M. Ångqvist, D. O. Lindroth, and P. Erhart
   | *Optimization of the Thermoelectric Power Factor:*
   | *Coupling between Chemical Order and Transport Properties*
   | Chemistry of Materials **28**, 6877 (2016)
   | `doi: 10.1021/acs.chemmater.6b02117 <http://dx.doi.org/10.1021/acs.chemmater.6b02117>`_
      
